@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2012 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.8. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.9. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *
  *   Class implementation of the approximate search algorithm
@@ -146,7 +146,7 @@ void approximatePattern::splitPattern()
     }
 }
 
-void approximatePattern::splitPattern(const QString& p, QStringList* w, QList<int>* ws, QList<int>* we) const
+void approximatePattern::splitPattern(const QString& p, QStringList* w, QList<int>* ws, QList<int>* we)
 {
     w->clear();
     ws->clear();
@@ -231,7 +231,7 @@ const QStringList approximatePattern::splitWord(const QString& word) const
         return QStringList() << word << word;
 }
 
-QString approximatePattern::wordPattern(const QString& word, Qt::CaseSensitivity cs) const
+QString approximatePattern::wordPattern(const QString& word, Qt::CaseSensitivity cs)
 {
     const int len(word.length());
     const QString ord(word.right(len - 1));
@@ -245,7 +245,7 @@ QString approximatePattern::wordPattern(const QString& word, Qt::CaseSensitivity
     return QString("(?:%1(?:%2)|%3)").arg(escape(word.at(0), cs)).arg(possible.join("|")).arg(escape(ord, cs));
 }
 
-int approximatePattern::wordCount(const QString& str) const
+int approximatePattern::wordCount(const QString& str)
 {
     const QString tstr(QString(str).replace(c2bUtils::nonLetter, " ").simplified());
     return 1 + tstr.count(' ');
