@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2012 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.8. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.9. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *
  *   Class implementation of the approximate search algorithm
@@ -71,13 +71,13 @@ public:
 
 
 private:
-    QString wordPattern(const QString& word, Qt::CaseSensitivity cs) const;
     const QStringList splitWord(const QString& word) const;
     int stretch(int piece_i, int piece_j) const;
-    int wordCount(const QString& str) const;
+    static QString wordPattern(const QString& word, Qt::CaseSensitivity cs);
+    static int wordCount(const QString& str);
+    static void splitPattern(const QString& p, QStringList* w, QList<int>* ws, QList<int>* we);
     void mergeIndices(int* index_in, const QString& str) const;
     void splitPattern();
-    void splitPattern(const QString& p, QStringList* w, QList<int>* ws, QList<int>* we) const;
 
     QList<int> _piece_ends;
     QList<int> _piece_starts;
