@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2012 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.8. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.9. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "authorString.h"
@@ -15,7 +15,7 @@
     or in the 'Abcd, E., F. Ghij, ...' mixed order.
 
 */
-authorString::authorString()
+authorString::authorString() : _full_form(false)
 {}
 
 
@@ -275,7 +275,7 @@ QString authorString::processFirstMiddle(const QString& first_middle) const
     return proc_fm;
 }
 
-QString authorString::capitalize(const QString& name) const
+QString authorString::capitalize(const QString& name)
 {
     // Capitalizes author's name
     if (name.isEmpty())
@@ -318,7 +318,7 @@ QString authorString::capitalize(const QString& name) const
     - Any other pattern -> Natural
 
 */
-bool authorString::isReverseOrder(const QString& author) const
+bool authorString::isReverseOrder(const QString& author)
 {
     // Returns true if Author Name is in reversed order as "Him DF, Her SR, "
     // ISI doesn't contain point - return for safety
@@ -358,7 +358,7 @@ bool authorString::isReverseOrder(const QString& author) const
     return false;
 }
 
-bool authorString::containLowerCaseLetter(const QString& author) const
+bool authorString::containLowerCaseLetter(const QString& author)
 {
     QString author_line(author);
     author_line.remove(QRegExp("\\band\\b")); // Remove possible 'and' separator
@@ -373,7 +373,7 @@ bool authorString::containLowerCaseLetter(const QString& author) const
     return false;
 }
 
-bool authorString::containUpperCaseLetter(const QString& author) const
+bool authorString::containUpperCaseLetter(const QString& author)
 {
     for (int i = 0; i < author.length(); i++)
     {
@@ -563,7 +563,7 @@ QString encoder::decoded(const int position, const int length) const
     return d;
 }
 
-bool encoder::isPlainWord(const QString& w) const
+bool encoder::isPlainWord(const QString& w)
 {
     if (w.length() > 1)
     {
@@ -576,7 +576,7 @@ bool encoder::isPlainWord(const QString& w) const
     return false;
 }
 
-bool encoder::isInitial(const QString& w) const
+bool encoder::isInitial(const QString& w)
 {
     if (w.length() == 1)
         if (w.at(0).isLetter())
@@ -588,7 +588,7 @@ bool encoder::isInitial(const QString& w) const
     return false;
 }
 
-bool encoder::isName(const QString& w) const
+bool encoder::isName(const QString& w)
 {
     if (w.length() < 2)
         return false;
@@ -599,7 +599,7 @@ bool encoder::isName(const QString& w) const
     return false;
 }
 
-bool encoder::isAdparticle(const QString& w) const
+bool encoder::isAdparticle(const QString& w)
 {
     const int ws(w.size());
     if (ws < 2)
