@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2012 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.8. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.9. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef AUTHORSTRING_H
@@ -119,7 +119,7 @@ struct encoder
             }
         }
     }
-    inline bool hasUpper(const QString& str) const
+    inline static bool hasUpper(const QString& str)
     {
         for (int i = 0; i < str.length(); i++)
             if (str.at(i).isLetter())
@@ -127,18 +127,18 @@ struct encoder
                     return true;
         return false;
     }
-    inline bool isCapitalName(const QString& w) const
+    inline static bool isCapitalName(const QString& w)
     {
         return c2bUtils::isUpperCaseString(w, qMax(0, w.lastIndexOf('_', -5))); // Skip prefixes and suffixes
     }
-    inline bool isSeparator(const QString& w) const
+    inline static bool isSeparator(const QString& w)
     {
         return (w == "and") || (w == "&");
     }
-    bool isAdparticle(const QString& w) const;
-    bool isInitial(const QString& w) const;
-    bool isName(const QString& w) const;
-    bool isPlainWord(const QString& w) const;
+    static bool isAdparticle(const QString& w);
+    static bool isInitial(const QString& w);
+    static bool isName(const QString& w);
+    static bool isPlainWord(const QString& w);
 };
 
 } // namespace author
@@ -155,14 +155,15 @@ public:
 
 
 private:
-    QString _author_string;
-    QString capitalize(const QString& name) const;
     QString processFirstMiddle(const QString& first_middle) const;
+    static QString capitalize(const QString& name);
+    static bool containLowerCaseLetter(const QString& author);
+    static bool containUpperCaseLetter(const QString& author);
+    static bool isReverseOrder(const QString& author);
+
+    QString _author_string;
     author::unifier as_unifier;
     bool _full_form;
-    bool containLowerCaseLetter(const QString& author) const;
-    bool containUpperCaseLetter(const QString& author) const;
-    bool isReverseOrder(const QString& author) const;
 
 };
 
