@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2012 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.8. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.9. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "collectionIndex.h"
@@ -30,7 +30,7 @@ class reversedsorting
 {
 public:
     inline reversedsorting() {}
-    inline bool operator()(const QString& si, const QString& sj)
+    inline bool operator()(const QString& si, const QString& sj) const
     {
         const int li(si.length());
         const int lj(sj.length());
@@ -668,7 +668,9 @@ bool collectionIndex::isValidKeySentence(const QString& text) const
         if (text.startsWith(QLatin1String("iii "))) return false;
         if (text.startsWith(QLatin1String("in "))) return false;
         if (text.startsWith(QLatin1String("initially "))) return false;
+        if (text.startsWith(QLatin1String("int j "))) return false;
         if (text.startsWith(QLatin1String("international conference on "))) return false;
+        if (text.startsWith(QLatin1String("international journal "))) return false;
         if (text.startsWith(QLatin1String("into "))) return false;
         if (text.startsWith(QLatin1String("is "))) return false;
         if (text.startsWith(QLatin1String("it "))) return false;
@@ -988,6 +990,7 @@ bool collectionIndex::isValidKeySentence(const QString& text) const
         if (text.endsWith(QLatin1String(" his"))) return false;
         if (text.endsWith(QLatin1String(" is"))) return false;
         if (text.endsWith(QLatin1String(" its"))) return false;
+        if (text.endsWith(QLatin1String(" ones"))) return false;
         if (text.endsWith(QLatin1String(" shows"))) return false;
         if (text.endsWith(QLatin1String(" this"))) return false;
         if (text.endsWith(QLatin1String(" us"))) return false;
