@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2012 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.8. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.9. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "compositePattern.h"
@@ -46,7 +46,7 @@ compositePattern::compositePattern(const QString& pattern, const Qt::CaseSensiti
 }
 
 
-QString compositePattern::escape(const QString& str, const Qt::CaseSensitivity cs) const
+QString compositePattern::escape(const QString& str, const Qt::CaseSensitivity cs)
 {
     if (cs == Qt::CaseSensitive)
         return QRegExp::escape(str);
