@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2012 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.8. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.9. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef COMPOSITEPATTERN_H
@@ -59,7 +59,7 @@ public:
 
 
 protected:
-    QString escape(const QString& str, const Qt::CaseSensitivity cs) const;
+    static QString escape(const QString& str, const Qt::CaseSensitivity cs);
     void set_sort_index();
 
     QList<double> _ranks;
