@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2012 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.8. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.9. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef DOCUMENTPARSER_H
@@ -35,7 +35,7 @@ public:
 private:
     int nextWord(const int pos) const;
 
-    inline bool _is_letter(const QChar& c) const
+    inline static bool _is_letter(const QChar& c)
     {
         const ushort uc(c.unicode());
         if ((uc > 96 && uc < 123) || uc == 95 || uc == 39)
@@ -43,7 +43,7 @@ private:
         else
             return c.isLetter();
     }
-    inline bool _is_letter_or_number(const QChar& c) const
+    inline static bool _is_letter_or_number(const QChar& c)
     {
         const ushort uc(c.unicode());
         if ((uc > 96 && uc < 123) || (uc > 47 && uc < 58) || uc == 95 || uc == 39)
