@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2012 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.8. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.9. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "heuristicBibParser.h"
@@ -17,6 +17,9 @@
 heuristicBibParser::heuristicBibParser(bibParser* bp) :
     _bpP(bp),
     _current_reference(bp->_current_reference),
+    _reliable_number(false),
+    _reliable_pages(false),
+    _reliable_volume(false),
     _abstract("abstract"),
     _addauthors("addauthors"),
     _author("author"),
@@ -363,7 +366,7 @@ QString heuristicBibParser::guessAuthor_multi_block()
     return author;
 }
 
-int heuristicBibParser::authorCount(const QString& authors) const
+int heuristicBibParser::authorCount(const QString& authors)
 {
     if (authors.isEmpty())
         return 0;
