@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2012 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.8. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.9. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef HEURISTICBIBPARSER_H
@@ -70,7 +70,7 @@ private:
     const QStringList& _bibliographic_fields;
     const journalDB& _journal_db;
     int _max_year;
-    int authorCount(const QString& authors) const;
+    static int authorCount(const QString& authors);
     void guessAbstract(const QString& text);
     void guessAuthor(const QString& tagged_text);
     void guessFromMetadata(const QString& text);
