@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2012 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.8. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.9. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef SEARCHPATTERN_H
@@ -97,7 +97,7 @@ private:
         bool match(const documentContents& contents) const;
         int index(const QString& contents, const int from) const;
 
-        inline bool _match_signature(const QString& ps, const QString& cs) const
+        inline static bool _match_signature(const QString& ps, const QString& cs)
         {
             const int pl(ps.length()); // Always pl > 0
             const int cl(cs.length());
@@ -113,7 +113,7 @@ private:
                         return true;
             return false;
         }
-        template <typename T> inline bool _match(const T& submatcher, const QString& psignature, const documentContents& contents) const
+        template <typename T> inline static bool _match(const T& submatcher, const QString& psignature, const documentContents& contents)
         {
             // Skip signature check for patterns that do not define it
             if (psignature.length() == 0 || _match_signature(psignature, contents.signature()))
