@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2012 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.8. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.9. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "settings.h"
@@ -54,7 +54,16 @@ void settings::init(bool command_line)
         _tmp_dir_path = _c2bApp->applicationDirPath();
     }
     else
-        _tmp_dir_path = QDir::homePath();
+    {
+        // Use user's home as tmp_dir since tmp files are more accessible if they are needed,
+        // for instance, for debugging netqinf
+        // Using cb2bib remotely causes tmp_dir not being writable, fallback to machine's tmp
+        const QFileInfo hpi(QDir::homePath());
+        if (hpi.exists() && hpi.isWritable())
+            _tmp_dir_path = QDir::homePath();
+        else
+            _tmp_dir_path = QDir::tempPath();
+    }
     setDefaults();
     // Set relative to BibTeX file in USB mode, overriding defaults.
     if (_is_usb_configured_mode)
