@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2012 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.8. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.9. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "texToHtml.h"
@@ -20,6 +20,14 @@ texToHtml::texToHtml() : texParser()
     _named_url_rx = QRegExp("\\b((?:file|http|https|ftp)://(?:[^\\s\\n\\r\\[]+))\\[([^\\]]*)\\]");
     _extern_url_rx = QRegExp("_((?:file|http|https|ftp)(?!.+\">)://(?:[^\\s\\n\\r\\[]+))(\\.[\\s\\n\\r]){0,1}");
     _url_rx = QRegExp("\\b((?:file|http|https|ftp)(?!.+\">)://(?:[^\\s\\n\\r\\[]+))(\\.[\\s\\n\\r]){0,1}");
+
+    _close_subsection = false;;
+    _close_subsubsection = false;;
+    _has_equation = false;;
+    _make_index = false;;
+    _use_relative_links = false;;
+    _index_anchors = 0;;
+
     _settingsP = settings::instance();
 }
 
