@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2012 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.8. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.9. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "wordMatcher.h"
@@ -10,10 +10,10 @@
 #include "cb2bib_utilities.h"
 
 
-wordMatcher::wordMatcher() : _hook(-1), _matched_length(-1)
+wordMatcher::wordMatcher() : _stretch(0), _hook(-1), _substring_count(0), _matched_length(-1), _p0(0), _pn(0)
 {}
 
-wordMatcher::wordMatcher(const QString& pattern, const Qt::CaseSensitivity cs)
+wordMatcher::wordMatcher(const QString& pattern, const Qt::CaseSensitivity cs) : _p0(0), _pn(0)
 {
     setPattern(pattern, cs);
 }
