@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2012 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.8. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.9. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "wordPattern.h"
@@ -10,7 +10,7 @@
 #include "triads.h"
 
 
-wordPattern::wordPattern() : compositePattern()
+wordPattern::wordPattern() : compositePattern(), _type(AllWords)
 {}
 
 wordPattern::wordPattern(const QString& pattern, const Type type, const Qt::CaseSensitivity cs) :
