@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2012 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.8. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.9. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bPostprocess.h"
@@ -94,9 +94,18 @@ void c2bPostprocess::PProcessFile()
 void c2bPostprocess::conversionEnded()
 {
     addToLog();
-    _buttonOpenFile->setEnabled(true);
     ui.buttonBox->button(QDialogButtonBox::Close)->setEnabled(true);
-    _buttonOpenFile->setFocus();
+    if (QFileInfo(_out).isReadable())
+    {
+        _buttonOpenFile->setEnabled(true);
+        _buttonOpenFile->setFocus();
+    }
+    else
+    {
+        ui.buttonBox->button(QDialogButtonBox::Close)->setAutoDefault(true);
+        ui.buttonBox->button(QDialogButtonBox::Close)->setDefault(true);
+        ui.buttonBox->button(QDialogButtonBox::Close)->setFocus();
+    }
     ui.Log->appendPlainText(tr("\n\nBibTeX Post Processing Command Ended."));
     delete _ppBibTeX;
 }
